@@ -4,7 +4,7 @@ from typing import Final
 
 from ecowitt2mqtt.helpers.typing import UnitSystemType
 
-__version__ = "2022.06.3"
+__version__ = "2022.06.6"
 
 
 LOGGER = logging.getLogger(__package__)
@@ -35,24 +35,24 @@ DATA_POINT_GLOB_BAROM: Final = "barom"
 DATA_POINT_GLOB_BATT: Final = "batt"
 DATA_POINT_GLOB_GUST: Final = "gust"
 DATA_POINT_GLOB_HUMIDITY: Final = "humidity"
+DATA_POINT_GLOB_LEAFBATT: Final = "leaf_batt"
+DATA_POINT_GLOB_LEAK: Final = "leak"
+DATA_POINT_GLOB_LEAKBATT: Final = "leakbatt"
 DATA_POINT_GLOB_MOISTURE: Final = "moisture"
 DATA_POINT_GLOB_PM10: Final = "pm10"
 DATA_POINT_GLOB_PM25: Final = "pm25"
+DATA_POINT_GLOB_PM25BATT: Final = "pm25batt"
 DATA_POINT_GLOB_RAIN: Final = "rain"
+DATA_POINT_GLOB_SOILBATT: Final = "soilbatt"
 DATA_POINT_GLOB_TEMP: Final = "temp"
+DATA_POINT_GLOB_TF: Final = "tf"
+DATA_POINT_GLOB_TF_BATT: Final = "tf_batt"
 DATA_POINT_GLOB_VOLT: Final = "volt"
+DATA_POINT_GLOB_WETNESS: Final = "wetness"
 DATA_POINT_GLOB_WIND: Final = "wind"
 DATA_POINT_GLOB_WINDDIR: Final = "winddir"
 
 # Data points (specific):
-DATA_POINT_BATTERY1: Final = "batt1"
-DATA_POINT_BATTERY2: Final = "batt2"
-DATA_POINT_BATTERY3: Final = "batt3"
-DATA_POINT_BATTERY4: Final = "batt4"
-DATA_POINT_BATTERY5: Final = "batt5"
-DATA_POINT_BATTERY6: Final = "batt6"
-DATA_POINT_BATTERY7: Final = "batt7"
-DATA_POINT_BATTERY8: Final = "batt8"
 DATA_POINT_CO2: Final = "co2"
 DATA_POINT_CO2_24H: Final = "co2_24h"
 DATA_POINT_CO2_BATT: Final = "co2_batt"
@@ -64,40 +64,17 @@ DATA_POINT_HEATINDEX: Final = "heatindex"
 DATA_POINT_HOURLY_RAIN: Final = "hourlyrain"
 DATA_POINT_HUMIDITY: Final = "humidity"
 DATA_POINT_HUMI_CO2: Final = "humi_co2"
-DATA_POINT_LEAKBATT1: Final = "leakbatt1"
-DATA_POINT_LEAKBATT2: Final = "leakbatt2"
-DATA_POINT_LEAKBATT3: Final = "leakbatt3"
-DATA_POINT_LEAKBATT4: Final = "leakbatt4"
-DATA_POINT_LEAKBATT5: Final = "leakbatt5"
-DATA_POINT_LEAKBATT6: Final = "leakbatt6"
-DATA_POINT_LEAKBATT7: Final = "leakbatt7"
-DATA_POINT_LEAKBATT8: Final = "leakbatt8"
 DATA_POINT_LIGHTNING: Final = "lightning"
 DATA_POINT_LIGHTNING_NUM: Final = "lightning_num"
 DATA_POINT_LIGHTNING_TIME: Final = "lightning_time"
 DATA_POINT_MONTHLY_RAIN: Final = "monthlyrain"
-DATA_POINT_PM25BATT1: Final = "pm25batt1"
-DATA_POINT_PM25BATT2: Final = "pm25batt2"
-DATA_POINT_PM25BATT3: Final = "pm25batt3"
-DATA_POINT_PM25BATT4: Final = "pm25batt4"
-DATA_POINT_PM25BATT5: Final = "pm25batt5"
-DATA_POINT_PM25BATT6: Final = "pm25batt6"
-DATA_POINT_PM25BATT7: Final = "pm25batt7"
-DATA_POINT_PM25BATT8: Final = "pm25batt8"
 DATA_POINT_RUNTIME: Final = "runtime"
-DATA_POINT_SOILBATT1: Final = "soilbatt1"
-DATA_POINT_SOILBATT2: Final = "soilbatt2"
-DATA_POINT_SOILBATT3: Final = "soilbatt3"
-DATA_POINT_SOILBATT4: Final = "soilbatt4"
-DATA_POINT_SOILBATT5: Final = "soilbatt5"
-DATA_POINT_SOILBATT6: Final = "soilbatt6"
-DATA_POINT_SOILBATT7: Final = "soilbatt7"
-DATA_POINT_SOILBATT8: Final = "soilbatt8"
 DATA_POINT_SOLARRADIATION: Final = "solarradiation"
 DATA_POINT_SOLARRADIATION_LUX: Final = "solarradiation_lux"
 DATA_POINT_SOLARRADIATION_PERCEIVED: Final = "solarradiation_perceived"
 DATA_POINT_TEMPF: Final = "tempf"
 DATA_POINT_TF_CO2: Final = "tf_co2"
+DATA_POINT_TOTAL_AIN: Final = "totalain"
 DATA_POINT_TOTAL_RAIN: Final = "totalrain"
 DATA_POINT_UV: Final = "uv"
 DATA_POINT_WEEKLY_RAIN: Final = "weeklyrain"
@@ -113,14 +90,6 @@ DATA_POINT_WH90BATT_PC: Final = "wh90battpc"
 DATA_POINT_WH90CAP_VOLT: Final = "ws90cap_volt"
 DATA_POINT_WINDCHILL: Final = "windchill"
 DATA_POINT_WINDSPEEDMPH: Final = "windspeedmph"
-DATA_POINT_WN34BATT1: Final = "tf_batt1"
-DATA_POINT_WN34BATT2: Final = "tf_batt2"
-DATA_POINT_WN34BATT3: Final = "tf_batt3"
-DATA_POINT_WN34BATT4: Final = "tf_batt4"
-DATA_POINT_WN34BATT5: Final = "tf_batt5"
-DATA_POINT_WN34BATT6: Final = "tf_batt6"
-DATA_POINT_WN34BATT7: Final = "tf_batt7"
-DATA_POINT_WN34BATT8: Final = "tf_batt8"
 DATA_POINT_YEARLY_RAIN: Final = "yearlyrain"
 
 # Environment variables:
