@@ -15,12 +15,15 @@ from ecowitt2mqtt.const import (
     DATA_POINT_GLOB_BATT,
     DATA_POINT_GLOB_GUST,
     DATA_POINT_GLOB_HUMIDITY,
+    DATA_POINT_GLOB_LEAK,
     DATA_POINT_GLOB_MOISTURE,
     DATA_POINT_GLOB_PM10,
     DATA_POINT_GLOB_PM25,
     DATA_POINT_GLOB_RAIN,
     DATA_POINT_GLOB_TEMP,
+    DATA_POINT_GLOB_TF,
     DATA_POINT_GLOB_VOLT,
+    DATA_POINT_GLOB_WETNESS,
     DATA_POINT_GLOB_WIND,
     DATA_POINT_GLOB_WINDDIR,
     DATA_POINT_HEATINDEX,
@@ -35,6 +38,7 @@ from ecowitt2mqtt.const import (
     DATA_POINT_SOLARRADIATION_PERCEIVED,
     DATA_POINT_TEMPF,
     DATA_POINT_TF_CO2,
+    DATA_POINT_TOTAL_AIN,
     DATA_POINT_UV,
     DATA_POINT_WINDCHILL,
     DATA_POINT_WINDSPEEDMPH,
@@ -43,6 +47,7 @@ from ecowitt2mqtt.const import (
 from ecowitt2mqtt.helpers.calculator import CalculatedDataPoint
 from ecowitt2mqtt.helpers.calculator.battery import calculate_battery
 from ecowitt2mqtt.helpers.calculator.distance import calculate_distance
+from ecowitt2mqtt.helpers.calculator.leak import calculate_leak
 from ecowitt2mqtt.helpers.calculator.meteo import (
     calculate_co2,
     calculate_dew_point,
@@ -84,12 +89,15 @@ CALCULATOR_FUNCTION_MAP: dict[str, Callable[..., CalculatedDataPoint]] = {
     DATA_POINT_GLOB_BATT: calculate_battery,
     DATA_POINT_GLOB_GUST: calculate_wind_speed,
     DATA_POINT_GLOB_HUMIDITY: calculate_humidity,
+    DATA_POINT_GLOB_LEAK: calculate_leak,
     DATA_POINT_GLOB_MOISTURE: calculate_moisture,
     DATA_POINT_GLOB_PM10: calculate_pm10,
     DATA_POINT_GLOB_PM25: calculate_pm25,
     DATA_POINT_GLOB_RAIN: calculate_rain_volume,
     DATA_POINT_GLOB_TEMP: calculate_temperature,
+    DATA_POINT_GLOB_TF: calculate_temperature,
     DATA_POINT_GLOB_VOLT: calculate_battery,
+    DATA_POINT_GLOB_WETNESS: calculate_moisture,
     DATA_POINT_GLOB_WIND: calculate_wind_speed,
     DATA_POINT_GLOB_WINDDIR: calculate_wind_dir,
     DATA_POINT_HEATINDEX: calculate_heat_index,
@@ -102,6 +110,7 @@ CALCULATOR_FUNCTION_MAP: dict[str, Callable[..., CalculatedDataPoint]] = {
     DATA_POINT_SOLARRADIATION_LUX: calculate_solar_radiation_lux,
     DATA_POINT_SOLARRADIATION_PERCEIVED: calculate_solar_radiation_perceived,
     DATA_POINT_TF_CO2: calculate_temperature,
+    DATA_POINT_TOTAL_AIN: calculate_rain_volume,
     DATA_POINT_UV: calculate_uv_index,
     DATA_POINT_WINDCHILL: calculate_wind_chill,
 }
@@ -122,6 +131,7 @@ UNIT_SUFFIX_MAP = {
     DATA_POINT_GLOB_RAIN: "in",
     DATA_POINT_GLOB_TEMP: "f",
     DATA_POINT_GLOB_WIND: "mph",
+    DATA_POINT_TOTAL_AIN: "in",
 }
 
 # Map calculated data points to the data points they depend on:
@@ -138,14 +148,10 @@ def get_calculator_function(
     ecowitt: Ecowitt, key: str
 ) -> partial[CalculatedDataPoint] | None:
     """Get a data calculator function for a particular data key (if it exists)."""
-    if (data_point := get_data_point_from_key(key)) is None:
+    data_point, func = glob_search(CALCULATOR_FUNCTION_MAP, key)
+    if not data_point or not func:
         return None
-    return partial(CALCULATOR_FUNCTION_MAP[data_point], ecowitt, key, data_point)
-
-
-def get_data_point_from_key(key: str) -> str | None:
-    """Get a data point from a key."""
-    return glob_search(CALCULATOR_FUNCTION_MAP, key)
+    return partial(func, ecowitt, key, data_point)
 
 
 def get_typed_value(value: T) -> float | T:
@@ -153,14 +159,16 @@ def get_typed_value(value: T) -> float | T:
     try:
         return float(value)  # type: ignore[arg-type]
     except Exception as err:  # pylint: disable=broad-except
-        LOGGER.warning("Couldn' convert value to number: %s", value)
+        LOGGER.warning("Couldn't convert value to number: %s", value)
         LOGGER.debug("".join(traceback.format_tb(err.__traceback__)))
         return value
 
 
 def remove_unit_from_key(key: str) -> str:
     """Remove a unit from the end of a key."""
-    if (data_point := get_data_point_from_key(key)) is None:
+    data_point, _ = glob_search(CALCULATOR_FUNCTION_MAP, key)
+
+    if not data_point:
         return key
 
     if (suffix := UNIT_SUFFIX_MAP.get(data_point)) is None or not key.endswith(suffix):
